<?php

/*
 * LMS version 1.11.7 Bastet
 *
 *  (C) Copyright 2001-2009 LMS Developers
 *
 *  Please, see the doc/AUTHORS for more information about authors!
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License Version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
 *  USA.
 *
 *  $Id: tariffdel.php,v 1.6 2009/01/13 07:45:54 alec Exp $
 */

$id = intval($_GET['id']);

if($id && $_GET['is_sure']=="1" && $LMS->TariffExists($id))
{
	if(!$DB->GetOne('SELECT COUNT(customerid) FROM assignments WHERE tariffid = ?', array($id)))
		$LMS->TariffDelete($id);	
}

$SESSION->redirect('?m=tarifflist');

?>
